@@ -1,4 +1,5 @@
 """Terminal user interface (TUI) helper functions and components."""
+from contextlib import nullcontext
 from pathlib import Path
 from typing import Any, List
 
@@ -7,7 +8,7 @@ from rich.theme import Theme
 
 from databooks import JupyterNotebook
 
-DATABOOKS_TUI = Theme({"in_count": "blue", "out_count": "orange3", "error": "on red"})
+DATABOOKS_TUI = Theme({"in_count": "blue", "out_count": "orange3", "kernel": "bold"})
 
 databooks_console = Console(theme=DATABOOKS_TUI)
 
@@ -19,7 +20,13 @@ def print_nb(path: Path, console: Console = databooks_console) -> None:
     console.print(notebook)
 
 
-def print_nbs(paths: List[Path], **kwargs_print_nb: Any) -> None:
+def print_nbs(
+    paths: List[Path],
+    console: Console = databooks_console,
+    use_pager: bool = False,
+    **kwargs_print_nb: Any
+) -> None:
     """Show rich representation of notebooks in terminal."""
-    for path in paths:
-        print_nb(path, **kwargs_print_nb)
+    with console.pager(styles=True) if use_pager else nullcontext():  # type: ignore
+        for path in paths:
+            print_nb(path, console=console, **kwargs_print_nb)
